"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        _log('Initializing with languages:', initialLanguages.map(l => l.name));
        _log('Initializing with themes:', initialThemes.map(t => t.name));
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }
        const defaultTheme = initialThemes[0];
        if (!defaultTheme || !defaultTheme.name) {
          throw new Error('Invalid theme format');
        }
        _log('Theme details:', {
          name: defaultTheme.name,
          type: defaultTheme.type,
          tokenColors: defaultTheme.tokenColors?.length,
          settings: defaultTheme.settings?.length,
          colors: Object.keys(defaultTheme.colors || {}).length
        });
        const engine = createJavaScriptRegexEngine({
          forgiving: true,
          cache: new Map()
        });
        _log('Created regex engine');

        // Process the theme's token rules
        const tokenColors = defaultTheme.tokenColors || [];
        const settings = tokenColors.map(color => ({
          scope: Array.isArray(color.scope) ? color.scope.filter(s => s !== undefined) : color.scope,
          settings: {
            foreground: color.settings.foreground,
            fontStyle: color.settings.fontStyle,
            background: color.settings.background
          }
        }));

        // Create a complete theme object with properly formatted rules
        const processedTheme = {
          name: defaultTheme.name,
          type: defaultTheme.type || 'dark',
          colors: defaultTheme.colors,
          settings: [
          // Default colors
          {
            settings: {
              foreground: defaultTheme.colors?.['editor.foreground'],
              background: defaultTheme.colors?.['editor.background']
            }
          },
          // Token-specific rules
          ...settings],
          fg: defaultTheme.colors?.['editor.foreground'],
          bg: defaultTheme.colors?.['editor.background']
        };
        _log('Processed theme:', {
          name: processedTheme.name,
          settings: processedTheme.settings?.length,
          firstRule: processedTheme.settings?.[1],
          fg: processedTheme.fg,
          bg: processedTheme.bg
        });
        const highlighterInstance = await createHighlighterCore({
          themes: [processedTheme],
          langs: initialLanguages,
          engine
        });

        // Test tokenization with specific scope and detailed logging
        try {
          const testCode = `
            function test() {
              const str = "hello";
              return str;
            }
          `;
          const testTokens = highlighterInstance.codeToTokens(testCode, {
            lang: 'typescript',
            theme: processedTheme.name,
            includeExplanation: true
          });
          _log('Test tokenization details:', {
            tokens: testTokens.tokens[0]?.map(t => ({
              content: t.content,
              color: t.color,
              scopes: t.explanation?.[0]?.scopes.map(s => s.scopeName),
              matches: t.explanation?.[0]?.scopes.map(s => s.themeMatches?.[0]?.settings)
            }))
          });
        } catch (e) {
          _log('Test tokenization failed:', e);
        }
        _log('Highlighter core created');

        // Validate languages were loaded
        const loadedLangs = highlighterInstance.getLoadedLanguages();
        _log('Loaded languages:', loadedLangs);
        if (loadedLangs.length === 0) {
          throw new Error('No languages were loaded');
        }

        // Set and validate theme
        const themeName = defaultTheme.name;
        highlighterInstance.setTheme(themeName);
        const loadedThemes = highlighterInstance.getLoadedThemes();
        _log('Loaded themes:', loadedThemes);
        if (!loadedThemes.includes(themeName)) {
          throw new Error(`Theme ${themeName} was not properly loaded`);
        }

        // Test tokenization
        try {
          const testTokens = highlighterInstance.codeToTokens('const test = "hello"', {
            lang: loadedLangs[0],
            theme: themeName
          });
          _log('Test tokenization result:', {
            success: true,
            tokenCount: testTokens.tokens.flat().length,
            firstToken: testTokens.tokens[0]?.[0]
          });
        } catch (e) {
          _log('Test tokenization failed:', e);
        }
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map